@@ -202,4 +202,40 @@ std::string FZ_PUBLIC_SYMBOL to_utf8(std::wstring const& in)
 	return ret;
 }
 
+namespace {
+template<typename String>
+inline void do_replace_substrings(String& in, String const& find, String const& replacement)
+{
+	size_t pos = in.find(find);
+	while (pos != std::string::npos) {
+		in.replace(pos, find.size(), replacement);
+		pos = in.find(find, pos + replacement.size());
+	}
+}
+}
+
+std::string replace_substrings(std::string const& in, std::string const& find, std::string const& replacement)
+{
+	std::string ret = in;
+	do_replace_substrings(ret, find, replacement);
+	return ret;
+}
+
+std::wstring replace_substrings(std::wstring const& in, std::wstring const& find, std::wstring const& replacement)
+{
+	std::wstring ret = in;
+	do_replace_substrings(ret, find, replacement);
+	return ret;
+}
+
+void replace_substrings(std::string& in, std::string const& find, std::string const& replacement)
+{
+	do_replace_substrings(in, find, replacement);
+}
+
+void replace_substrings(std::wstring& in, std::wstring const& find, std::wstring const& replacement)
+{
+	do_replace_substrings(in, find, replacement);
+}
+
 }
